/****************************************************************************
** QgsNorthArrowPlugin meta object code from reading C++ file 'plugin.h'
**
** Created: Fri Nov 4 14:26:06 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "plugin.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsNorthArrowPlugin::className() const
{
    return "QgsNorthArrowPlugin";
}

QMetaObject *QgsNorthArrowPlugin::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsNorthArrowPlugin( "QgsNorthArrowPlugin", &QgsNorthArrowPlugin::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsNorthArrowPlugin::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsNorthArrowPlugin", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsNorthArrowPlugin::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsNorthArrowPlugin", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsNorthArrowPlugin::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QObject::staticMetaObject();
    static const QUMethod slot_0 = {"initGui", 0, 0 };
    static const QUMethod slot_1 = {"projectRead", 0, 0 };
    static const QUMethod slot_2 = {"run", 0, 0 };
    static const QUParameter param_slot_3[] = {
	{ 0, &static_QUType_ptr, "QPainter", QUParameter::In }
    };
    static const QUMethod slot_3 = {"renderNorthArrow", 1, param_slot_3 };
    static const QUParameter param_slot_4[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_4 = {"rotationChanged", 1, param_slot_4 };
    static const QUMethod slot_5 = {"refreshCanvas", 0, 0 };
    static const QUMethod slot_6 = {"unload", 0, 0 };
    static const QUMethod slot_7 = {"help", 0, 0 };
    static const QUParameter param_slot_8[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_8 = {"setPlacement", 1, param_slot_8 };
    static const QUParameter param_slot_9[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_9 = {"setEnabled", 1, param_slot_9 };
    static const QUParameter param_slot_10[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_10 = {"setAutomatic", 1, param_slot_10 };
    static const QUParameter param_slot_11[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_11 = {"calculateNorthDirection", 1, param_slot_11 };
    static const QMetaData slot_tbl[] = {
	{ "initGui()", &slot_0, QMetaData::Public },
	{ "projectRead()", &slot_1, QMetaData::Public },
	{ "run()", &slot_2, QMetaData::Public },
	{ "renderNorthArrow(QPainter*)", &slot_3, QMetaData::Public },
	{ "rotationChanged(int)", &slot_4, QMetaData::Public },
	{ "refreshCanvas()", &slot_5, QMetaData::Public },
	{ "unload()", &slot_6, QMetaData::Public },
	{ "help()", &slot_7, QMetaData::Public },
	{ "setPlacement(QString)", &slot_8, QMetaData::Public },
	{ "setEnabled(bool)", &slot_9, QMetaData::Public },
	{ "setAutomatic(bool)", &slot_10, QMetaData::Public },
	{ "calculateNorthDirection()", &slot_11, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsNorthArrowPlugin", parentObject,
	slot_tbl, 12,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsNorthArrowPlugin.setMetaObject( metaObj );
    return metaObj;
}

void* QgsNorthArrowPlugin::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsNorthArrowPlugin" ) )
	return this;
    if ( !qstrcmp( clname, "QgisPlugin" ) )
	return (QgisPlugin*)this;
    return QObject::qt_cast( clname );
}

bool QgsNorthArrowPlugin::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: initGui(); break;
    case 1: projectRead(); break;
    case 2: run(); break;
    case 3: renderNorthArrow((QPainter*)static_QUType_ptr.get(_o+1)); break;
    case 4: rotationChanged((int)static_QUType_int.get(_o+1)); break;
    case 5: refreshCanvas(); break;
    case 6: unload(); break;
    case 7: help(); break;
    case 8: setPlacement((QString)static_QUType_QString.get(_o+1)); break;
    case 9: setEnabled((bool)static_QUType_bool.get(_o+1)); break;
    case 10: setAutomatic((bool)static_QUType_bool.get(_o+1)); break;
    case 11: static_QUType_bool.set(_o,calculateNorthDirection()); break;
    default:
	return QObject::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsNorthArrowPlugin::qt_emit( int _id, QUObject* _o )
{
    return QObject::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsNorthArrowPlugin::qt_property( int id, int f, QVariant* v)
{
    return QObject::qt_property( id, f, v);
}

bool QgsNorthArrowPlugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
